extractRegime extracts the specified regime from the GMAR or StMAR model's parameter vector. Doesn't extract mixing weight parameter alpha.
extractRegime(p, M, params, StMAR = FALSE, restricted = FALSE,
constraints = FALSE, R, regime)a positive integer specifying the order of AR coefficients.
a positive integer specifying the number of mixture components or regimes.
a real valued parameter vector specifying the model.
Size \((M(p+3)-1x1)\) vector \(\theta\)\(=\)(\(\upsilon_{1}\),...,\(\upsilon_{M}\), \(\alpha_{1},...,\alpha_{M-1}\)), where \(\upsilon_{m}\)\(=(\phi_{m,0},\)\(\phi_{m}\)\(, \sigma_{m}^2)\) and \(\phi_{m}\)=\((\phi_{m,1},...,\phi_{m,p}), m=1,...,M\).
Size \((M(p+4)-1x1)\) vector (\(\theta, \nu\))\(=\)(\(\upsilon_{1}\),...,\(\upsilon_{M}\), \(\alpha_{1},...,\alpha_{M-1}, \nu_{1},...,\nu_{M}\)).
Replace the vectors \(\phi_{m}\) with vectors \(\psi_{m}\) and provide a list of constraint matrices R that satisfy \(\phi_{m}\)\(=\)\(R_{m}\psi_{m}\) for all \(m=1,...,M\), where \(\psi_{m}\)\(=(\psi_{m,1},...,\psi_{m,q_{m}})\).
Size \((3M+p-1x1)\) vector \(\theta\)\(=(\phi_{1,0},...,\phi_{M,0},\)\(\phi\)\(, \sigma_{1}^2,...,\sigma_{M}^2,\alpha_{1},...,\alpha_{M-1})\), where \(\phi\)=\((\phi_{1},...,\phi_{M})\).
Size \((4M+p-1x1)\) vector (\(\theta, \nu\))\(=(\phi_{1,0},...,\phi_{M,0},\)\(\phi\)\(, \sigma_{1}^2,...,\sigma_{M}^2,\alpha_{1},...,\alpha_{M-1}, \nu_{1},...,\nu_{M})\).
Replace the vector \(\phi\) with vector \(\psi\) and provide a constraint matrix \(R\) that satisfies \(\phi\)\(=\)\(R\psi\), where \(\psi\)\(=(\psi_{1},...,\psi_{q})\).
Symbol \(\phi\) denotes an AR coefficient, \(\sigma^2\) a variance, \(\alpha\) a mixing weight and \(v\) a degrees of freedom parameter. Note that in the case M=1 the parameter \(\alpha\) is dropped, and in the case of StMAR model the degrees of freedom parameters \(\nu_{m}\) have to be larger than \(2\).
an (optional) logical argument stating whether StMAR model should be considered instead of GMAR model. Default is FALSE.
an (optional) logical argument stating whether the AR coefficients \(\phi_{m,1},...,\phi_{m,p}\) are restricted
to be the same for all regimes. Default is FALSE.
an (optional) logical argument stating whether general linear constraints should be applied to the model. Default is FALSE.
Specifies the linear constraints.
a list of size \((pxq_{m})\) constraint matrices \(R_{m}\) of full column rank satisfying \(\phi_{m}\)\(=\)\(R_{m}\psi_{m}\) for all \(m=1,...,M\), where \(\phi_{m}\)\(=(\phi_{m,1},...,\phi_{m,p})\) and \(\psi_{m}\)\(=(\psi_{m,1},...,\psi_{m,q_{m}})\).
a size \((pxq)\) constraint matrix \(R\) of full column rank satisfying \(\phi\)\(=\)\(R\psi\), where \(\phi\)\(=(\phi_{1},...,\phi_{p})\) and \(\psi\)\(=\psi_{1},...,\psi_{q}\).
Symbol \(\phi\) denotes an AR coefficient. Note that regardless of any constraints, the nominal order of AR coefficients is alway p for all regimes.
This argument is ignored if constraints==FALSE.
a positive integer in the closed interval [1, M] defining which regime should be extracted.
Returns a numeric vector corresponding to the regime with...
Size \((p+2x1)\) vector \((\phi_{m,0},\phi_{m,1},...,\phi_{m,p}, \sigma_{m}^2)\).
Size \((p+3x1)\) vector \((\phi_{m,0},\phi_{m,1},...,\phi_{m,p}, \sigma_{m}^2, \nu_{m})\).
Parameter vector as descripted above, but vector \(\phi_{m}\) replaced with vector \(\psi_{m}\) that satisfies \(\phi_{m}\)\(=\)\(R_{m}\psi_{m}\).
Size \((2x1)\) vector \((\phi_{m,0}, \sigma_{m}^2)\).
Size \((3x1)\) vector \((\phi_{m,0}, \sigma_{m}^2, \nu_{m})\).
Parameter vector as descripted above.